Glossary — pyramid_jinja2 2.1 documentation

### Navigation

- index
- modules |
- previous |
- pyramid_jinja2 2.1 documentation »

# Glossary

Asset Specification
  A string representing the path to a directory or file present in a Python module. See Understanding Asset Specifications in the Pyramid documentation for more information.
Configurator
  `pyramid.config.Configurator`
Jinja2
  A templating system written by Armin Ronacher.
Pyramid
  A web framework.
pyramid_jinja2
  A set of bindings that make templates written for the Jinja2 templating system work under the Pyramid web framework.
Template Inheritance
  Allows you to build a base “skeleton” template that contains all the common elements of your site and defines blocks that child templates can override. See Template Inheritance in the Jinja2 documentation.

### Navigation

- index
- modules |
- previous |
- pyramid_jinja2 2.1 documentation »